==> vradi-entities-0.2.0-sources.jar: com/jurismarches/vradi/entities/Status.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.TreeNode;
import org.nuiton.wikitty.TreeNodeAbstract;
import org.nuiton.wikitty.TreeNodeImpl;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface Status extends BusinessEntity {     String EXT_STATUS = "Status";
     String FIELD_STATUS_NAME = "name";
     String FQ_FIELD_STATUS_NAME = EXT_STATUS + ".name";
     String FIELD_STATUS_VALUE = "value";
     String FQ_FIELD_STATUS_VALUE = EXT_STATUS + ".value";
     String FIELD_STATUS_DESCRIPTION = "description";
     String FQ_FIELD_STATUS_DESCRIPTION = EXT_STATUS + ".description";
     String FIELD_STATUS_MODIFIABLE = "modifiable";
     String FQ_FIELD_STATUS_MODIFIABLE = EXT_STATUS + ".modifiable";
    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * setName :
     * @param name 
     */

     void setName(String name);

    /**
     * getValue :
     * @return int 
     */

     int getValue();

    /**
     * setValue :
     * @param value 
     */

     void setValue(int value);

    /**
     * getDescription :
     * @return String 
     */

     String getDescription();

    /**
     * setDescription :
     * @param description 
     */

     void setDescription(String description);

    /**
     * getModifiable :
     * @return boolean 
     */

     boolean getModifiable();

    /**
     * setModifiable :
     * @param modifiable 
     */

     void setModifiable(boolean modifiable);


} //Status

==> vradi-entities-0.3.2-sources.jar: com/jurismarches/vradi/entities/Status.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyTreeNode;
import org.nuiton.wikitty.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.WikittyTreeNodeImpl;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface Status extends BusinessEntity {     String EXT_STATUS = "Status";
     String FIELD_STATUS_NAME = "name";
     String FQ_FIELD_STATUS_NAME = EXT_STATUS + ".name";
     String FIELD_STATUS_VALUE = "value";
     String FQ_FIELD_STATUS_VALUE = EXT_STATUS + ".value";
     String FIELD_STATUS_DESCRIPTION = "description";
     String FQ_FIELD_STATUS_DESCRIPTION = EXT_STATUS + ".description";
     String FIELD_STATUS_MODIFIABLE = "modifiable";
     String FQ_FIELD_STATUS_MODIFIABLE = EXT_STATUS + ".modifiable";
    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * setName :
     * @param name 
     */

     void setName(String name);

    /**
     * getValue :
     * @return int 
     */

     int getValue();

    /**
     * setValue :
     * @param value 
     */

     void setValue(int value);

    /**
     * getDescription :
     * @return String 
     */

     String getDescription();

    /**
     * setDescription :
     * @param description 
     */

     void setDescription(String description);

    /**
     * getModifiable :
     * @return boolean 
     */

     boolean getModifiable();

    /**
     * setModifiable :
     * @param modifiable 
     */

     void setModifiable(boolean modifiable);


} //Status
